pub fn get_latency_row(
reply: MeasurementReply,
rx_worker_id: &u32,
worker_map: &BiHashMap<u32, String>,
origin_id: u32,
) -> Vec<String>Expand description
Get the result (csv row) from a Reply message
Arguments
reply- The Reply that is being written to this rowrx_worker_id- The worker ID of the receiverworker_map- A map of worker IDs to hostnames, used to convert worker IDs to hostnames in the resultsorigin_id- origin ID associated with the reply
Returns
A vector of strings representing the row in the CSV file